from resources.lib.const import STORAGE, SERVICE_EVENT, SERVICE, SETTINGS
from resources.lib.kodilogging import service_logger
from resources.lib.services import Service
from resources.lib.storage.settings import settings
from resources.lib.storage.sqlite import SQLiteStorage
from resources.lib.storage.storage import storage


class PlayerService(Service):
    SERVICE_NAME = SERVICE.PLAYER_SERVICE

    def __init__(self, api):
        super(PlayerService, self).__init__()
        self._api = api
        self._event_callbacks = {
            SERVICE_EVENT.PLAYBACK_STARTED: self.media_played,
            SERVICE_EVENT.PLAYBACK_STOPPED: self.media_stopped
        }
        self.db = SQLiteStorage.WatchHistory()

    def media_played(self, media_id):
        service_logger.debug('Sending API request to increment play count')
        self._api.media_played(media_id)
        if settings.as_bool(SETTINGS.PLAYED_ITEMS_HISTORY):
            self.db.add(media_id)

    @staticmethod
    def media_stopped():
        service_logger.debug('Playback stopped.')
